==> custom_pages-v1.12.4.zip: custom_pages/messages/zh-TW/base.php <==
<?php

return [
    '<strong>Custom</strong> Pages' => '<strong>自訂</strong>頁面',
    '<strong>Edit</strong> snippet' => '<strong>編輯</strong>提示',
    'Add' => '添加',
    'Back' => '返回',
    'Back to dashboard' => '返回儀表板',
    'Category' => '類別',
    'Configuration' => '設定',
    'Content' => '内容',
    'Create' => '建立',
    'Dashboard' => '儀表板',
    'Default' => '預設值',
    'Default Content' => '預設內容',
    'Delete' => '刪除',
    'Edit' => '編輯',
    'Edit Page' => '編輯頁面',
    'File' => '文件',
    'General' => '一般資訊',
    'Insert' => '插入',
    'Public' => '公開貼文',
    'Settings' => '設定',
    'Sort Order' => '排列順序',
    'Space' => 'Space',
    'Spaces' => 'Space',
    'Stream' => '塗鴉牆',
    'Submit' => '送出',
    'Title' => '標題',
    'Topics' => '主題',
    'Type' => '類型',
    'Upload image' => '上傳圖像',
    'Visibility' => '貼文能見度',
    '<strong>Add</strong> {templateName} item' => '',
    'Add a file icon before the title' => '',
    'Additional IFrame Attributes' => '',
    'Adds plain HTML content to your site.' => '',
    'Administrative Users' => '',
    'Advanced' => '',
    'Allows the user to manage custom pages.' => '',
    'Allows to add pages (markdown, iframe or links) to the space navigation' => '',
    'Allows you to add content in MarkDown syntax.' => '',
    'Alternate text' => '',
    'Always' => '',
    'Always make a backup of your view files outside of your production environment!' => '',
    'An empty allowed template selection will allow all container templates for this container.' => '',
    'Authors' => '',
    'Back to overview' => '',
    'Back to space' => '',
    'Can manage custom pages' => '',
    'Cannot delete!' => '',
    'Container' => '',
    'Content filters' => '',
    'Css Class' => '',
    'Custom' => '',
    'Custom Pages' => '',
    'Custom pages' => '',
    'Deleted.' => '',
    'Empty' => '',
    'Empty content elements cannot be deleted!' => '',
    'Enter post content ID' => '',
    'Footer menu' => '',
    'Global Page' => '',
    'Global Widget' => '',
    'Go Back' => '',
    'Html' => '',
    'ID' => '',
    'Icon' => '',
    'Iframe' => '',
    'Import' => '',
    'Invalid request data!' => '',
    'Invalid template selection!' => '',
    'Invalid type selection' => '',
    'Invalid view file selection!' => '',
    'Layout' => '',
    'Leave empty to list all records related to the current user.' => '',
    'Limit' => '',
    'Link' => '',
    'Logged-In Users' => '',
    'Manage layouts, snippet layouts, and containers. Layouts define page structures, snippet layouts are used in sidebars or sections, and containers are reusable content blocks.' => '',
    'MarkDown' => '',
    'Menu settings' => '',
    'Navigation' => '',
    'Non-Logged-In Users' => '',
    'On this page you can configure general settings of your custom pages.' => '',
    'Overview' => '',
    'PHP' => '',
    'Page' => '',
    'Page Content' => '',
    'Pages' => '',
    'Panel' => '',
    'People Buttons' => '',
    'Please choose one of the following content types. The content type defines how your content is embedded to your site.' => '',
    'Please keep in mind that php based pages are vulnerable to security issues, especially when handling user input. For more information, please have a look at <a href="{url}">Yii\'s Security best practices</a>.' => '',
    'Reset' => '',
    'Reset the content to default value' => '',
    'Resources' => '',
    'Restrict to following comma separated content IDs' => '',
    'Select this setting for visible text nodes only. Uncheck this setting in case this element is used for example as HTML attribute value.' => '',
    'Show additional file information (size)' => '',
    'Snippet' => '',
    'Snippets' => '',
    'Source' => '',
    'Space Members only' => '',
    'Space Navigation' => '',
    'Space Page' => '',
    'Space Widget' => '',
    'Start Page' => '',
    'Stream options' => '',
    'Style' => '',
    'Style Class' => '',
    'Target Url' => '',
    'Template' => '',
    'Template Layout' => '',
    'Templates' => '',
    'Templates allow you to define combinable page fragments with inline edit functionality.' => '',
    'This container does not allow any further items!' => '',
    'Top Navigation' => '',
    'Usage' => '',
    'User Account Menu (Settings)' => '',
    'Will embed the result of a given url as an iframe element.' => '',
    'Will redirect requests to a given (relative or absolute) url.' => '',
    'With PHP based pages you can create custom pages by means of view files in your file system. Please check the module configuration for more Information.' => '',
    'Without adding to navigation (Direct link)' => '',
    'Wrap this HTML page with white panel' => '',
    'You are not allowed to delete default content!' => '',
];

==> custom_pages-v1.12.14.zip: custom_pages/messages/zh-TW/base.php <==
<?php

return [
    '<strong>Custom</strong> Pages' => '<strong>自訂</strong>頁面',
    '<strong>Edit</strong> snippet' => '<strong>編輯</strong>提示',
    'Add' => '添加',
    'Back' => '返回',
    'Back to dashboard' => '返回儀表板',
    'Category' => '類別',
    'Configuration' => '設定',
    'Content' => '内容',
    'Create' => '建立',
    'Dashboard' => '儀表板',
    'Default' => '預設值',
    'Default Content' => '預設內容',
    'Delete' => '刪除',
    'Edit' => '編輯',
    'Edit Page' => '編輯頁面',
    'File' => '文件',
    'General' => '一般資訊',
    'Insert' => '插入',
    'Public' => '公開貼文',
    'Settings' => '設定',
    'Sort Order' => '排列順序',
    'Space' => 'Space',
    'Spaces' => 'Space',
    'Stream' => '塗鴉牆',
    'Submit' => '送出',
    'Title' => '標題',
    'Topics' => '主題',
    'Type' => '類型',
    'Upload image' => '上傳圖像',
    'Visibility' => '貼文能見度',
    '<strong>Add</strong> {templateName} item' => '',
    'Activities' => '',
    'Activity' => '',
    'Activity content ID' => '',
    'Add a file icon before the title' => '',
    'Additional IFrame Attributes' => '',
    'Adds plain HTML content to your site.' => '',
    'Administrative Users' => '',
    'Advanced' => '',
    'Allows the user to manage custom pages.' => '',
    'Allows to add pages (markdown, iframe or links) to the space navigation' => '',
    'Allows you to add content in MarkDown syntax.' => '',
    'Alternate text' => '',
    'Always' => '',
    'Always make a backup of your view files outside of your production environment!' => '',
    'An empty allowed template selection will allow all container templates for this container.' => '',
    'Authors' => '',
    'Back to overview' => '',
    'Back to space' => '',
    'By creation date' => '',
    'By last update' => '',
    'Can manage custom pages' => '',
    'Cannot delete!' => '',
    'Container' => '',
    'Content filters' => '',
    'Css Class' => '',
    'Custom' => '',
    'Custom Pages' => '',
    'Custom pages' => '',
    'Deleted.' => '',
    'Determine which Spaces should be taken into account.' => '',
    'Empty' => '',
    'Empty content elements cannot be deleted!' => '',
    'Enter post content ID' => '',
    'Footer menu' => '',
    'Global Page' => '',
    'Global Widget' => '',
    'Go Back' => '',
    'Html' => '',
    'ID' => '',
    'Icon' => '',
    'Iframe' => '',
    'Import' => '',
    'Include all Spaces except selected' => '',
    'Include selected Spaces only' => '',
    'Invalid request data!' => '',
    'Invalid template selection!' => '',
    'Invalid type selection' => '',
    'Invalid view file selection!' => '',
    'Layout' => '',
    'Leave empty to list all records related to the current user.' => '',
    'Limit' => '',
    'Link' => '',
    'Logged-In Users' => '',
    'Manage layouts, snippet layouts, and containers. Layouts define page structures, snippet layouts are used in sidebars or sections, and containers are reusable content blocks.' => '',
    'MarkDown' => '',
    'Menu settings' => '',
    'Navigation' => '',
    'Non-Logged-In Users' => '',
    'On this page you can configure general settings of your custom pages.' => '',
    'Overview' => '',
    'PHP' => '',
    'Page' => '',
    'Page Content' => '',
    'Pages' => '',
    'Panel' => '',
    'People Buttons' => '',
    'Please choose one of the following content types. The content type defines how your content is embedded to your site.' => '',
    'Please keep in mind that php based pages are vulnerable to security issues, especially when handling user input. For more information, please have a look at <a href="{url}">Yii\'s Security best practices</a>.' => '',
    'Reset' => '',
    'Reset the content to default value' => '',
    'Resources' => '',
    'Restrict to following comma separated content IDs' => '',
    'Select this setting for visible text nodes only. Uncheck this setting in case this element is used for example as HTML attribute value.' => '',
    'Show additional file information (size)' => '',
    'Snippet' => '',
    'Snippets' => '',
    'Sorting' => '',
    'Source' => '',
    'Space Members only' => '',
    'Space Navigation' => '',
    'Space Page' => '',
    'Space Widget' => '',
    'Space selection' => '',
    'Start Page' => '',
    'Stream options' => '',
    'Style' => '',
    'Style Class' => '',
    'Target Url' => '',
    'Template' => '',
    'Template Layout' => '',
    'Templates' => '',
    'Templates allow you to define combinable page fragments with inline edit functionality.' => '',
    'This container does not allow any further items!' => '',
    'Top Navigation' => '',
    'Usage' => '',
    'User Account Menu (Settings)' => '',
    'Will embed the result of a given url as an iframe element.' => '',
    'Will redirect requests to a given (relative or absolute) url.' => '',
    'With PHP based pages you can create custom pages by means of view files in your file system. Please check the module configuration for more Information.' => '',
    'Without adding to navigation (Direct link)' => '',
    'Wrap this HTML page with white panel' => '',
    'You are not allowed to delete default content!' => '',
];
